==> haskell-js-dgtable-0.5.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-dgtable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-dgtable
version:              0.5.2
visibility:           public
id:                   js-dgtable-0.5.2-3xYZc81Mz3XEyBJwQyLDFO
key:                  js-dgtable-0.5.2-3xYZc81Mz3XEyBJwQyLDFO
license:              MIT
copyright:            Neil Mitchell 2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-dgtable#readme
synopsis:             Obtain minified jquery.dgtable code
description:
    This package bundles the minified <https://github.com/danielgindi/jquery.dgtable jquery.dgtable> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jquery.dgtable version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  f1dfd2def98214952ccada0981da8f19
exposed:              True
exposed-modules:      Language.Javascript.DGTable
hidden-modules:       Paths_js_dgtable
import-dirs:          /usr/lib/ghc-8.10.4/site-local/js-dgtable-0.5.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/js-dgtable-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/js-dgtable-0.5.2
hs-libraries:         HSjs-dgtable-0.5.2-3xYZc81Mz3XEyBJwQyLDFO
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-js-dgtable/html/js-dgtable.haddock
haddock-html:         /usr/share/doc/haskell-js-dgtable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-dgtable-0.5.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-js-dgtable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 js-dgtable
version:              0.5.2
visibility:           public
id:                   js-dgtable-0.5.2-8TmXPIzeYbw6g9bjhRY7XA
key:                  js-dgtable-0.5.2-8TmXPIzeYbw6g9bjhRY7XA
license:              MIT
copyright:            Neil Mitchell 2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-dgtable#readme
synopsis:             Obtain minified jquery.dgtable code
description:
    This package bundles the minified <https://github.com/danielgindi/jquery.dgtable jquery.dgtable> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jquery.dgtable version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  02ba3ea6c7a40020ad5599e752dfdd7e
exposed:              True
exposed-modules:      Language.Javascript.DGTable
hidden-modules:       Paths_js_dgtable
import-dirs:          /usr/lib/ghc-9.0.1/site-local/js-dgtable-0.5.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/js-dgtable-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/js-dgtable-0.5.2
hs-libraries:         HSjs-dgtable-0.5.2-8TmXPIzeYbw6g9bjhRY7XA
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-js-dgtable/html/js-dgtable.haddock
haddock-html:         /usr/share/doc/haskell-js-dgtable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
